@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Draw fretboard chord diagrams
 
-our $VERSION = '0.1302';
+our $VERSION = '0.1303';
 
 use Moo;
 use strictures 2;
@@ -13,6 +13,10 @@ use Imager ();
 use List::SomeUtils 'first_index';
 use Music::Chord::Namer 'chordname';
 
+use constant WHITE => 'white';
+use constant BLACK => 'black';
+use constant TAN   => 'tan';
+
 
 has chord => (
     is => 'rw',
@@ -162,9 +166,6 @@ sub draw {
         return $self->_draw_horiz;
     }
 
-    my $WHITE = 'white';
-    my $BLACK = 'black';
-    my $TAN   = 'tan';
     my $SPACE = $self->size;
 
     my $font;
@@ -174,7 +175,7 @@ sub draw {
         xsize => $SPACE + $self->strings * $SPACE,
         ysize => $SPACE + $self->frets * $SPACE,
     );
-    $i->box( filled => 1, color => $WHITE );
+    $i->box( filled => 1, color => WHITE );
 
     if ( -e $self->font ) {
         $font = Imager::Font->new( file => $self->font );
@@ -200,7 +201,7 @@ sub draw {
             $i->string(
                 font  => $font,
                 text  => $self->position,
-                color => $BLACK,
+                color => BLACK,
                 x     => $SPACE / 4,
                 y     => $SPACE * 2 + $SPACE / 4,
                 size  => $SPACE / 2,
@@ -210,7 +211,7 @@ sub draw {
 
         if ( $self->_fret_match($fret) ) {
             $i->circle(
-                color => $TAN,
+                color => TAN,
                 r     => $SPACE / 8,
                 x     => $SPACE * $self->strings / 2 + $SPACE / 2,
                 y     => $SPACE + $fret * $SPACE + $SPACE / 2,
@@ -250,7 +251,7 @@ sub draw {
                 $i->string(
                     font  => $font,
                     text  => 'X',
-                    color => $BLACK,
+                    color => BLACK,
                     x     => $SPACE + ($self->strings - $string) * $SPACE - $SPACE / 6,
                     y     => $SPACE - 2,
                     size  => $SPACE / 2,
@@ -266,7 +267,7 @@ sub draw {
                 $i->string(
                     font  => $font,
                     text  => 'O',
-                    color => $BLACK,
+                    color => BLACK,
                     x     => $SPACE + ($self->strings - $string) * $SPACE - $SPACE / 6,
                     y     => $SPACE - 2,
                     size  => $SPACE / 2,
@@ -302,7 +303,7 @@ sub draw {
             $i->string(
                 font  => $font,
                 text  => $chord_name,
-                color => $BLACK,
+                color => BLACK,
                 x     => $SPACE,
                 y     => ($self->frets + 1) * $SPACE - $SPACE / 3,
                 size  => $SPACE / 2,
@@ -322,9 +323,6 @@ sub draw {
 sub _draw_horiz {
     my ($self) = @_;
 
-    my $WHITE = 'white';
-    my $BLACK = 'black';
-    my $TAN   = 'tan';
     my $SPACE = $self->size;
 
     my $font;
@@ -334,7 +332,7 @@ sub _draw_horiz {
         ysize => $SPACE + $self->strings * $SPACE,
         xsize => $SPACE + $self->frets * $SPACE,
     );
-    $i->box( filled => 1, color => $WHITE );
+    $i->box( filled => 1, color => WHITE );
 
     if ( -e $self->font ) {
         $font = Imager::Font->new( file => $self->font );
@@ -360,7 +358,7 @@ sub _draw_horiz {
             $i->string(
                 font  => $font,
                 text  => $self->position,
-                color => $BLACK,
+                color => BLACK,
                 y     => $SPACE / 2 + $SPACE / 5,
                 x     => $SPACE * 2 - $SPACE / 5,
                 size  => $SPACE / 2,
@@ -370,7 +368,7 @@ sub _draw_horiz {
 
         if ( $self->_fret_match($fret) ) {
             $i->circle(
-                color => $TAN,
+                color => TAN,
                 r     => $SPACE / 8,
                 y     => $SPACE * $self->strings / 2 + $SPACE / 2,
                 x     => $SPACE + $fret * $SPACE + $SPACE / 2,
@@ -410,7 +408,7 @@ sub _draw_horiz {
                 $i->string(
                     font  => $font,
                     text  => 'X',
-                    color => $BLACK,
+                    color => BLACK,
                     y     => $SPACE + ($string - 1) * $SPACE + $SPACE / 4,
                     x     => $SPACE - $SPACE / 2,
                     size  => $SPACE / 2,
@@ -426,7 +424,7 @@ sub _draw_horiz {
                 $i->string(
                     font  => $font,
                     text  => 'O',
-                    color => $BLACK,
+                    color => BLACK,
                     y     => $SPACE + ($string - 1) * $SPACE + $SPACE / 4,
                     x     => $SPACE - $SPACE / 2,
                     size  => $SPACE / 2,
@@ -448,7 +446,7 @@ sub _draw_horiz {
                     r     => $SPACE / 5,
                     x     => $x,
                     y     => $SPACE + ($string - 1) * $SPACE,
-                );
+                ) if $x < $SPACE * $self->frets;
             }
 
             # Increment the current string number
@@ -462,7 +460,7 @@ sub _draw_horiz {
             $i->string(
                 font  => $font,
                 text  => $chord_name,
-                color => $BLACK,
+                color => BLACK,
                 x     => $SPACE,
                 y     => ($self->strings + 1) * $SPACE - $SPACE / 3,
                 size  => $SPACE / 2,
@@ -529,7 +527,7 @@ Music::FretboardDiagram - Draw fretboard chord diagrams
 
 =head1 VERSION
 
-version 0.1302
+version 0.1303
 
 =head1 SYNOPSIS
 
